@@ -54,8 +54,12 @@ __all__ = (
     "CancelPolicyGenerationRequestRequestTypeDef",
     "TrailTypeDef",
     "TrailPropertiesTypeDef",
+    "EbsSnapshotConfigurationTypeDef",
+    "EcrRepositoryConfigurationTypeDef",
+    "EfsFileSystemConfigurationTypeDef",
     "IamRoleConfigurationTypeDef",
     "SecretsManagerSecretConfigurationTypeDef",
+    "SnsTopicConfigurationTypeDef",
     "SqsQueueConfigurationTypeDef",
     "ResponseMetadataTypeDef",
     "DeleteAnalyzerRequestRequestTypeDef",
@@ -83,6 +87,8 @@ __all__ = (
     "SubstringTypeDef",
     "PolicyGenerationDetailsTypeDef",
     "PositionTypeDef",
+    "RdsDbClusterSnapshotAttributeValueTypeDef",
+    "RdsDbSnapshotAttributeValueTypeDef",
     "S3PublicAccessBlockConfigurationTypeDef",
     "StartResourceScanRequestRequestTypeDef",
     "TagResourceRequestRequestTypeDef",
@@ -122,6 +128,8 @@ __all__ = (
     "NetworkOriginConfigurationTypeDef",
     "PathElementTypeDef",
     "SpanTypeDef",
+    "RdsDbClusterSnapshotConfigurationTypeDef",
+    "RdsDbSnapshotConfigurationTypeDef",
     "ListAccessPreviewsResponseTypeDef",
     "GetAnalyzerResponseTypeDef",
     "ListAnalyzersResponseTypeDef",
@@ -290,6 +298,32 @@ class TrailPropertiesTypeDef(_RequiredTrailPropertiesTypeDef, _OptionalTrailProp
     pass
 
 
+EbsSnapshotConfigurationTypeDef = TypedDict(
+    "EbsSnapshotConfigurationTypeDef",
+    {
+        "userIds": Sequence[str],
+        "groups": Sequence[str],
+        "kmsKeyId": str,
+    },
+    total=False,
+)
+
+EcrRepositoryConfigurationTypeDef = TypedDict(
+    "EcrRepositoryConfigurationTypeDef",
+    {
+        "repositoryPolicy": str,
+    },
+    total=False,
+)
+
+EfsFileSystemConfigurationTypeDef = TypedDict(
+    "EfsFileSystemConfigurationTypeDef",
+    {
+        "fileSystemPolicy": str,
+    },
+    total=False,
+)
+
 IamRoleConfigurationTypeDef = TypedDict(
     "IamRoleConfigurationTypeDef",
     {
@@ -307,6 +341,14 @@ SecretsManagerSecretConfigurationTypeDef = TypedDict(
     total=False,
 )
 
+SnsTopicConfigurationTypeDef = TypedDict(
+    "SnsTopicConfigurationTypeDef",
+    {
+        "topicPolicy": str,
+    },
+    total=False,
+)
+
 SqsQueueConfigurationTypeDef = TypedDict(
     "SqsQueueConfigurationTypeDef",
     {
@@ -631,6 +673,22 @@ PositionTypeDef = TypedDict(
     },
 )
 
+RdsDbClusterSnapshotAttributeValueTypeDef = TypedDict(
+    "RdsDbClusterSnapshotAttributeValueTypeDef",
+    {
+        "accountIds": Sequence[str],
+    },
+    total=False,
+)
+
+RdsDbSnapshotAttributeValueTypeDef = TypedDict(
+    "RdsDbSnapshotAttributeValueTypeDef",
+    {
+        "accountIds": Sequence[str],
+    },
+    total=False,
+)
+
 S3PublicAccessBlockConfigurationTypeDef = TypedDict(
     "S3PublicAccessBlockConfigurationTypeDef",
     {
@@ -639,13 +697,27 @@ S3PublicAccessBlockConfigurationTypeDef = TypedDict(
     },
 )
 
-StartResourceScanRequestRequestTypeDef = TypedDict(
-    "StartResourceScanRequestRequestTypeDef",
+_RequiredStartResourceScanRequestRequestTypeDef = TypedDict(
+    "_RequiredStartResourceScanRequestRequestTypeDef",
     {
         "analyzerArn": str,
         "resourceArn": str,
     },
 )
+_OptionalStartResourceScanRequestRequestTypeDef = TypedDict(
+    "_OptionalStartResourceScanRequestRequestTypeDef",
+    {
+        "resourceOwnerAccount": str,
+    },
+    total=False,
+)
+
+
+class StartResourceScanRequestRequestTypeDef(
+    _RequiredStartResourceScanRequestRequestTypeDef, _OptionalStartResourceScanRequestRequestTypeDef
+):
+    pass
+
 
 TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
@@ -1231,6 +1303,24 @@ SpanTypeDef = TypedDict(
     },
 )
 
+RdsDbClusterSnapshotConfigurationTypeDef = TypedDict(
+    "RdsDbClusterSnapshotConfigurationTypeDef",
+    {
+        "attributes": Mapping[str, RdsDbClusterSnapshotAttributeValueTypeDef],
+        "kmsKeyId": str,
+    },
+    total=False,
+)
+
+RdsDbSnapshotConfigurationTypeDef = TypedDict(
+    "RdsDbSnapshotConfigurationTypeDef",
+    {
+        "attributes": Mapping[str, RdsDbSnapshotAttributeValueTypeDef],
+        "kmsKeyId": str,
+    },
+    total=False,
+)
+
 ListAccessPreviewsResponseTypeDef = TypedDict(
     "ListAccessPreviewsResponseTypeDef",
     {
@@ -1547,10 +1637,16 @@ GetGeneratedPolicyResponseTypeDef = TypedDict(
 ConfigurationTypeDef = TypedDict(
     "ConfigurationTypeDef",
     {
+        "ebsSnapshot": EbsSnapshotConfigurationTypeDef,
+        "ecrRepository": EcrRepositoryConfigurationTypeDef,
         "iamRole": IamRoleConfigurationTypeDef,
+        "efsFileSystem": EfsFileSystemConfigurationTypeDef,
         "kmsKey": KmsKeyConfigurationTypeDef,
+        "rdsDbClusterSnapshot": RdsDbClusterSnapshotConfigurationTypeDef,
+        "rdsDbSnapshot": RdsDbSnapshotConfigurationTypeDef,
         "secretsManagerSecret": SecretsManagerSecretConfigurationTypeDef,
         "s3Bucket": S3BucketConfigurationTypeDef,
+        "snsTopic": SnsTopicConfigurationTypeDef,
         "sqsQueue": SqsQueueConfigurationTypeDef,
     },
     total=False,
